# MCP Server

The Model Context Protocol (MCP) server provides access to the Yiqijian API. This server allows the use of the Yiqijian open interface to implement the function of providing video copy and generating videos
